==> haskell-wai-handler-launch-3.0.2.3-29-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-handler-launch
version: 3.0.2.3
id: wai-handler-launch-3.0.2.3-LPQrb2xitYKDDrwx3rD6IS
key: wai-handler-launch-3.0.2.3-LPQrb2xitYKDDrwx3rD6IS
license: MIT
maintainer: michael@snoyman.com
synopsis: Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.
category: Web
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Network.Wai.Handler.Launch
abi: b7345433605a6c8a6ddf7227643df92a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wai-handler-launch-3.0.2.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/wai-handler-launch-3.0.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/wai-handler-launch-3.0.2.3
hs-libraries: HSwai-handler-launch-3.0.2.3-LPQrb2xitYKDDrwx3rD6IS
depends:
    async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd base-4.10.1.0
    blaze-builder-0.4.0.2-LgKKusoD6S36d41ySZ5Ski bytestring-0.10.8.2
    http-types-0.9.1-BnmUD9RxZRhHekChwpKApV process-1.6.1.0
    streaming-commons-0.1.19-4dQF1GxaRjPAXtCn2ZaIy1
    transformers-0.5.2.0 wai-3.2.1.1-JM87vg9uknZGvXXydqppYS
    warp-3.2.17-2jlwMPzvvsK2VRKNy394DW
abi-depends: async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd=576b92c3ea42677785425376467cda48
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             blaze-builder-0.4.0.2-LgKKusoD6S36d41ySZ5Ski=ca4639e6cf9a757510daffd0af64d66d
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             http-types-0.9.1-BnmUD9RxZRhHekChwpKApV=17904082cafa5b41bdd6c56cc1e99042
             process-1.6.1.0=df30c64bceb5deb119c7833d040aa380
             streaming-commons-0.1.19-4dQF1GxaRjPAXtCn2ZaIy1=cb67c8d9e2b8badf5f2765b0bdb953b6
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             wai-3.2.1.1-JM87vg9uknZGvXXydqppYS=e59b573ecb4a53343d760a19fea60b09
             warp-3.2.17-2jlwMPzvvsK2VRKNy394DW=ab99f457ae406a2be0847ec668cf52ac
haddock-interfaces: /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock
haddock-html: /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-handler-launch-3.0.2.3-41-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-handler-launch
version: 3.0.2.3
id: wai-handler-launch-3.0.2.3-E034X8102Jl5GbYGtene57
key: wai-handler-launch-3.0.2.3-E034X8102Jl5GbYGtene57
license: MIT
maintainer: michael@snoyman.com
synopsis: Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.
category: Web
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Network.Wai.Handler.Launch
abi: 92bc92318c8a3301cc6a7e675b2842ef
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wai-handler-launch-3.0.2.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/wai-handler-launch-3.0.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/wai-handler-launch-3.0.2.3
hs-libraries: HSwai-handler-launch-3.0.2.3-E034X8102Jl5GbYGtene57
depends:
    async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd base-4.10.1.0
    blaze-builder-0.4.0.2-LgKKusoD6S36d41ySZ5Ski bytestring-0.10.8.2
    http-types-0.9.1-HaxgCYZbcak8u9TfZKlScE process-1.6.1.0
    streaming-commons-0.1.19-GTZ4hjI5qOY6KXQ7oSU718
    transformers-0.5.2.0 wai-3.2.1.1-KVYy9SB2igV2T5xcgijEyy
    warp-3.2.18.1-BJFEdqPSrv5HNbsNdRGAb0
abi-depends: async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd=576b92c3ea42677785425376467cda48
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             blaze-builder-0.4.0.2-LgKKusoD6S36d41ySZ5Ski=ca4639e6cf9a757510daffd0af64d66d
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             http-types-0.9.1-HaxgCYZbcak8u9TfZKlScE=33f0582260438c22e48ef849288f31d3
             process-1.6.1.0=df30c64bceb5deb119c7833d040aa380
             streaming-commons-0.1.19-GTZ4hjI5qOY6KXQ7oSU718=0787b481b92c56e594f1c53cf7b44681
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             wai-3.2.1.1-KVYy9SB2igV2T5xcgijEyy=695bca3b5db5d006c8b145794e3bdfca
             warp-3.2.18.1-BJFEdqPSrv5HNbsNdRGAb0=6b6c30d455c2c277238fa796430d1a49
haddock-interfaces: /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock
haddock-html: /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
